const { getHeaders } = require('../helpers/get-headers')
const { makeRequest } = require('../helpers/make-request')
module.exports = {
  friendlyName: 'Bulk create transfer recipient',
  description: 'Create multiple transfer recipients in batches.',
  extendedDescription: 'A duplicate account number will lead to the retrieval of the existing record.',
  cacheable: false,
  sync: false,
  inputs: {
    apiKey: require('../constants/apiKey.input'),
    batch: {
      description: 'A list of transfer recipient object',
      extendedDescription: 'Each object should contain type, name, and bank_code. Any Create Transfer Recipient param can also be passed.',
      example: [{
        type: 'nuban',
        name: 'Harry Potter',
        account_number: '3094540263',
        bank_code: '044'
      }],
      required: true
    }
  },
  exits: {
    success: {
      description: 'Done.'
    }

  },
  fn: function ({ apiKey, batch }, exits) {
    makeRequest('/transferrecipient/bulk',
      {
        method: 'POST',
        headers: getHeaders(apiKey || process.env.PAYSTACK_API_KEY),
        body: JSON.stringify(batch)
      }).then((response) => {
      return exits.success(response)
    }).catch(error => {
      return exits.error(error)
    })
  }

}
