const { getHeaders } = require('../helpers/get-headers')
const { makeRequest } = require('../helpers/make-request')

module.exports = {

  friendlyName: 'charge',

  description: 'Initiate a payment by integrating the payment channel of your choice.',

  cacheable: false,

  sync: false,

  inputs: {
    apiKey: require('../constants/apiKey.input'),
    email: {
      description: 'Customer\'s email address',
      example: 'customer@email.com',
      required: true
    },
    amount: {
      description: 'Amount should be in kobo if currency is NGN, pesewas for GHS, cents for USD',
      example: 10000,
      required: true
    },
    bank: {
      description: 'Bank account to charge (don\'t send if charging an authorization code)',
      example: {
        bank: {
          code: '057',
          account_number: '0000000000'
        }
      }
    },
    authorization_code: {
      description: 'An authorization code to charge (don\'t send if charging a bank account)',
      example: 'AUTH_6tmt288t0o'
    },
    pin: {
      description: '4-digit PIN (send with a non-reusable authorization code)',
      example: '1234'
    },
    metadata: {
      description: 'A JSON object',
      example: {
        metadata: {
          custom_fields: [
            {
              value: 'makurdi',
              display_name: 'Donation for',
              variable_name: 'donation_for'
            }
          ]
        }
      }
    },
    reference: {
      description: 'Unique transaction reference. Only -, .`, = and alphanumeric characters allowed.',
      example: 'zuvbpizfcf2fs7y'
    },
    ussd: {
      description: 'USSD type to charge (don\'t send if charging an authorization code, bank or card)',
      example: {}
    },
    mobile_money: {
      description: 'Mobile details (don\'t send if charging an authorization code, bank or card)',
      example: {}
    },
    device_id: {
      description: 'This is the unique identifier of the device a user uses in making payment.',
      extendedDescription: 'Only -, .`, = and alphanumeric characters allowed.',
      example: 'unique_device_id'
    }
  },

  exits: {
    success: {
      outputDescription: 'Charge attempted'
    }
  },

  fn: function ({ apiKey, ...params }, exits) {
    makeRequest('/charge', {
      method: 'POST',
      headers: getHeaders(apiKey || process.env.PAYSTACK_API_KEY),
      body: JSON.stringify(params)
    })
      .then(chargeAttempted => exits.success(chargeAttempted))
      .catch(error => exits.error(error))
  }

}
