const { getHeaders } = require('../helpers/get-headers')
const { makeRequest } = require('../helpers/make-request')

module.exports = {
  friendlyName: 'Check Pending Charge',
  description: 'When you get "pending" as a charge status or if there was an exception when calling any of the /charge endpoints, wait 10 seconds or more, then make a check to see if its status has changed.',
  extendedDescription: 'Don\'t call too early as you may get a lot more pending than you should.',
  cacheable: false,
  sync: false,
  inputs: {
    apiKey: require('../constants/apiKey.input'),
    reference: {
      description: 'The reference to check',
      example: '367705b2-b9b0-5bcf-81bf-a0e6e0853bed',
      required: true
    }
  },
  exits: {
    success: {
      outputDescription: 'Charge attempted'
    }
  },
  fn: function ({ apiKey, reference }, exits) {
    makeRequest(`/charge/${reference}`, {
      headers: getHeaders(apiKey || process.env.PAYSTACK_API_KEY)
    })
      .then(chargeAttempted => exits.success(chargeAttempted))
      .catch(error => exits.error(error))
  }
}
