const { getHeaders } = require('../helpers/get-headers')
const { makeRequest } = require('../helpers/make-request')
module.exports = {

  friendlyName: 'Create transfer recipient',

  description: 'Creates a new recipient',

  extendedDescription: 'A duplicate account number will lead to the retrieval of the existing record.',

  cacheable: false,

  sync: false,

  inputs: {
    apiKey: require('../constants/apiKey.input'),
    type: {
      description: 'Recipient type',
      example: 'nuban',
      required: true
    },
    name: {
      description: 'A name for the recipient',
      example: 'Awesome Customer',
      required: true
    },
    account_number: {
      description: 'Required if type is nuban',
      example: '01000000010',
      required: true
    },
    bank_code: {
      description: 'Required if type is nuban. You can get the list of Bank Codes by calling the .listBanks machine',
      example: '044',
      required: true
    },
    description: {
      description: 'A description for the transfer',
      example: 'Transfer for crypto asset'
    },
    currency: {
      description: 'Currency of the account receiving the transfer',
      example: 'ngn'
    },
    authorization_code: {
      description: 'An authorization code from a previous transaction',
      example: 'AU_464nkfhnfk'
    },
    metadata: {
      description: 'Store additional information about your recipient in a structured format, JSON',
      example: {}
    }
  },
  exits: {
    success: {
      description: 'Done.'
    }
  },

  fn: function ({ apiKey, ...bodyParams }, exits) {
    makeRequest('/transferrecipient',
      {
        method: 'POST',
        headers: getHeaders(apiKey || process.env.PAYSTACK_API_KEY),
        body: JSON.stringify(bodyParams)
      }).then((response) => {
      return exits.success(response)
    }).catch(error => {
      return exits.error(error)
    })
  }
}
