const { getHeaders } = require('../helpers/get-headers')
const { makeRequest } = require('../helpers/make-request')

module.exports = {

  friendlyName: 'Disable transfers Otp',

  description: 'This is used in the event that you want to be able to complete transfers programmatically without use of OTPs.',

  extendedDescription: 'No arguments requred. You will get an OTP to complete the request.',

  cacheable: false,

  sync: false,

  inputs: {
    apiKey: require('../constants/apiKey.input'),
    transfer_code: {
      description: 'Transfer code',
      example: 'TRF_vsyqdmlzble3uii',
      required: true
    }
  },

  exits: {

    success: {
      variableName: 'result',
      description: 'Done.'
    }

  },

  fn: function ({ apiKey, ...bodyParams }, exits) {
    makeRequest('/transfer/disable_otp', {
      method: 'POST',
      headers: getHeaders(apiKey || process.env.PAYSTACK_API_KEY),
      body: JSON.stringify(bodyParams)
    }).then(response => exits.success(response)
    ).catch(error => {
      return exits.error(error)
    })
  }
}
