const { getHeaders } = require('../helpers/get-headers')
const { makeRequest } = require('../helpers/make-request')

module.exports = {

  friendlyName: 'Enable transfers Otp',

  description: 'In the event that a customer wants to stop being able to complete transfers programmatically, this endpoint helps turn OTP requirement back on. No arguments required.',

  cacheable: false,

  sync: false,

  inputs: {
    apiKey: require('../constants/apiKey.input'),
    transfer_code: {
      description: 'Transfer code',
      example: 'TRF_vsyqdmlzble3uii',
      required: true
    }
  },

  exits: {
    success: {
      variableName: 'result',
      description: 'Done.'
    }
  },

  fn: function ({ apiKey, ...bodyParams }, exits) {
    makeRequest('/transfer/disable_otp', {
      method: 'POST',
      headers: getHeaders(apiKey || process.env.PAYSTACK_API_KEY),
      body: JSON.stringify(bodyParams)
    }).then(response => exits.success(response)
    ).catch(error => {
      return exits.error(error)
    })
  }

}
