const { getHeaders } = require('../helpers/get-headers')
const { getQueryStringFromObject } = require('../helpers/get-query-string-from-object')
const { makeRequest } = require('../helpers/make-request')
module.exports = {

  friendlyName: 'Export Disputes',

  description: 'Export Disputes available on your integration',

  cacheable: false,

  sync: false,

  inputs: {
    apiKey: require('../constants/apiKey.input'),
    from: {
      description: 'A timestamp from which to start listing dispute',
      example: '2021-01-01',
      required: true
    },
    to: {
      description: 'A timestamp at which to stop listing dispute',
      example: '2021-04-01',
      required: false
    },
    perPage: require('../constants/perPage.input'),
    page: require('../constants/page.input'),
    transaction: {
      description: 'Transaction ID',
      example: 1234
    },
    status: {
      description: 'Dispute Status',
      extendedDescription: 'Acceptable values: { awaiting-merchant-feedback | awaiting-bank-feedback | pending | resolved }',
      example: 'awaiting-merchant-feedback'
    }
  },

  exits: {
    success: {
      outputDescription: 'Export successful'
    }
  },

  fn: function ({ apiKey, ...params }, exits) {
    const queryParams = getQueryStringFromObject(params)
    makeRequest(`/dispute/export?${queryParams}`,
      {
        headers: getHeaders(apiKey || process.env.PAYSTACK_API_KEY)
      }).then((disputeExport) => {
      return exits.success(disputeExport)
    }).catch(error => {
      return exits.error(error)
    })
  }

}
