
const { getQueryStringFromObject } = require('../helpers/get-query-string-from-object')
const _ = require('@sailshq/lodash')
const { getHeaders } = require('../helpers/get-headers')
const { makeRequest } = require('../helpers/make-request')

module.exports = {

  friendlyName: 'Fetch balance ledger',

  description: 'Fetch all pay-ins and pay-outs that occured on your integration',

  cacheable: false,

  sync: false,

  inputs: {
    apiKey: require('../constants/apiKey.input'),
    perPage: require('../constants/perPage.input'),
    page: require('../constants/page.input')
  },

  exits: {
    success: {
      variableName: 'result',
      description: 'Done.'
    }
  },

  fn: function ({ apiKey, ...params }, exits) {
    const queryParams = _.isEmpty(params) ? null : getQueryStringFromObject(params)
    const endpoint = _.isNull(queryParams) ? '/balance/ledger' : `/balance/ledger?${queryParams}`
    makeRequest(endpoint, {
      headers: getHeaders(apiKey || process.env.PAYSTACK_API_KEY)
    })
      .then(response => exits.success(response))
      .catch(error => exits.error(error))
  }
}
