const { getHeaders } = require('../helpers/get-headers')
const { makeRequest } = require('../helpers/make-request')

module.exports = {
  friendlyName: 'Fetch Bulk Charge Batch',
  description: 'This endpoint retrieves a specific batch code',
  extendedDescription: ' It also returns useful information on its progress by way of the total_charges and pending_charges attributes.',
  cacheable: false,
  sync: false,
  inputs: {
    apiKey: require('../constants/apiKey.input'),
    id_or_code: {
      example: 'BCH_180tl7oq7cayggh',
      description: 'An ID or code for the charge whose batches you want to retrieve.',
      required: true
    }
  },

  exits: {
    success: {
      outputDescription: 'Bulk charge retrieved'
    }
  },

  fn: function ({ apiKey, id_or_code }, exits) {
    makeRequest(`/bulkcharge/${id_or_code}`, {
      headers: getHeaders(apiKey || process.env.PAYSTACK_API_KEY)
    }).then((bulkcharge) => {
      return exits.success(bulkcharge)
    }).catch(error => {
      return exits.error(error)
    })
  }

}
