const { getQueryStringFromObject } = require('../helpers/get-query-string-from-object')
const { makeRequest } = require('../helpers/make-request')
const { getHeaders } = require('../helpers/get-headers')

module.exports = {

  friendlyName: 'Fetch Charges in a Batch',

  description: 'This endpoint retrieves the charges associated with a specified batch code. Pagination parameters are available.',

  extendedDescription: 'You can also filter by status. Charge statuses can be pending, success or failed.',

  cacheable: false,

  sync: false,

  inputs: {
    apiKey: require('../constants/apiKey.input'),
    id_or_code: {
      example: '18',
      description: 'An ID or code for the batch whose batches you want to retrieve.',
      required: true
    },
    status: {
      description: 'Either one of these values: pending, success or failed',
      example: 'pending',
      required: true
    },
    perPage: require('../constants/perPage.input'),
    page: require('../constants/page.input'),
    from: {
      description: 'A timestamp from which to start listing charges',
      example: '2021-01-01'
    },
    to: {
      description: 'A timestamp at which to stop listing charges',
      example: '2021-04-01'
    }
  },

  exits: {
    success: {
      outputDescription: 'Bulk charge items retrieved'
    }

  },

  fn: function ({ apiKey, id_or_code, ...params }, exits) {
    const queryParams = getQueryStringFromObject(params)
    makeRequest(`/bulkcharge/${id_or_code}/charges?${queryParams}`, {
      headers: getHeaders(apiKey || process.env.PAYSTACK_API_KEY)
    }).then(bulkChargeItemsRetrieved => exits.success(bulkChargeItemsRetrieved))
      .catch(error => exits.error(error))
  }

}
