const { getHeaders } = require('../helpers/get-headers')
const { makeRequest } = require('../helpers/make-request')

module.exports = {

  friendlyName: 'Get Upload URL',

  description: 'Get URL to upload a dispute evidence',

  cacheable: false,

  sync: false,

  inputs: {
    apiKey: require('../constants/apiKey.input'),
    id: {
      description: 'The dispute ID you want to get the upload URL for',
      example: '1234',
      required: true
    },
    upload_filename: {
      description: 'The file name, with its extension, that you want to upload.',
      example: 'filename.pdf',
      required: true
    }

  },

  exits: {
    success: {
      outputDescription: 'Upload URL generated'
    }
  },

  fn: function ({ apiKey, id, upload_filename }, exits) {
    makeRequest(`/dispute/${id}/upload_url?upload_filename=${upload_filename}`, {
      headers: getHeaders(apiKey || process.env.PAYSTACK_API_KEY)
    }).then(generatedUrl => exits.success(generatedUrl))
      .catch(error => exits.error(error))
  }

}
