const { getHeaders } = require('../helpers/get-headers')
const { makeRequest } = require('../helpers/make-request')
module.exports = {
  friendlyName: 'Initiate Bulk Charge',
  description: 'Send an array of objects with authorization codes and amount, in kobo if currency is NGN and pesewas, if currency is GHS. so we can process transactions as a batch.',
  cacheable: false,
  sync: false,
  inputs: {
    apiKey: require('../constants/apiKey.input'),
    charges: {
      description: 'A list of charge object. Each object consists of an authorization and amount',
      example: [{ authorization: 'AUTH_n95vpedf', amount: 2500 }, { authorization: 'AUTH_ljdt4e4j', amount: 1500 }],
      required: true
    }
  },
  exits: {
    success: {
      outputDescription: 'Charges have been queued'
    }
  },
  fn: function ({ apiKey, charges }, exits) {
    makeRequest('/bulkcharge', {
      method: 'POST',
      headers: getHeaders(apiKey || process.env.PAYSTACK_API_KEY),
      body: JSON.stringify(charges)
    }).then(chargesQueued => exits.success(chargesQueued))
      .catch(error => exits.error(error))
  }
}
