const { getHeaders } = require('../helpers/get-headers')
const { makeRequest } = require('../helpers/make-request')
module.exports = {

  friendlyName: 'Initiate bulk transfer',

  description: 'You need to disable the Transfers OTP requirement to use this endpoint.',

  cacheable: false,

  sync: false,

  inputs: {
    apiKey: require('../constants/apiKey.input'),
    source: {
      description: 'Where should we transfer from? Only balance for now',
      example: 'balance',
      required: true
    },
    transfers: {
      description: 'A list of transfer object. Each object should contain amount, recipient, and reference',
      example: [
        {
          recipient: 'RCP_db342dvqvz9qcrn',
          amount: 50000,
          reference: 'ref_943899312'
        }
      ],
      required: true
    }
  },
  exits: {
    success: {
      variableName: 'result',
      description: 'Done.'
    }
  },
  fn: function ({ apiKey, ...bodyParams }, exits) {
    makeRequest('/transfer/bulk',
      {
        method: 'POST',
        headers: getHeaders(apiKey || process.env.PAYSTACK_API_KEY),
        body: JSON.stringify(bodyParams)
      }).then((response) => {
      return exits.success(response)
    }).catch(error => {
      return exits.error(error)
    })
  }

}
