const { getHeaders } = require('../helpers/get-headers')
const { makeRequest } = require('../helpers/make-request')
module.exports = {
  friendlyName: 'Initiate transfer',
  description: 'Status of transfer object returned will be pending if OTP is disabled. In the event that an OTP is required, status will read otp.',
  cacheable: false,
  sync: false,
  inputs: {
    apiKey: require('../constants/apiKey.input'),
    source: {
      description: 'Where should we transfer from? Only balance for now',
      example: 'balance',
      required: true
    },
    amount: {
      description: 'Amount to transfer in kobo if currency is NGN and pesewas if currency in GHS',
      example: 3794800,
      required: true
    },
    recipient: {
      description: 'Code for transfer recipient',
      example: 'RCP_gx2wn530m0i3w3m',
      required: true
    },
    reason: {
      description: 'The reason for the transfer',
      example: 'Sailscasts subscription'
    },
    currency: {
      description: 'Specify the currency of the transfer. Defaults to NGN',
      example: 'NGN'
    },
    reference: {
      description: 'If specified, the field should be a unique identifier(in lowercase_ for the object.',
      extendedDescription: 'Only -, _ and alphanumeric character allowed',
      example: '_unique'
    }
  },
  exits: {
    success: {
      variableName: 'result',
      description: 'Done.'
    }
  },

  fn: function ({ apiKey, ...bodyParams }, exits) {
    makeRequest('/transfer',
      {
        method: 'POST',
        headers: getHeaders(apiKey || process.env.PAYSTACK_API_KEY),
        body: JSON.stringify(bodyParams)
      }).then((response) => {
      return exits.success(response)
    }).catch(error => {
      return exits.error(error)
    })
  }

}
