const { getQueryStringFromObject } = require('../helpers/get-query-string-from-object')
const { makeRequest } = require('../helpers/make-request')
const _ = require('@sailshq/lodash')
const { getHeaders } = require('../helpers/get-headers')

module.exports = {
  friendlyName: 'List Bulk Charges Batches',
  description: 'This lists all bulk charge batches created by the integration. Statuses can be active, paused, or complete.',
  cacheable: false,
  sync: false,
  inputs: {
    apiKey: require('../constants/apiKey.input'),
    perPage: require('../constants/perPage.input'),
    page: require('../constants/page.input'),
    from: {
      description: 'A timestamp from which to start listing batches e.g. 2016-09-24T00:00:05.000Z, 2016-09-21',
      example: '2016-09-21'
    },
    to: {
      description: 'A timestamp at which to stop listing batches e.g. 2016-09-24T00:00:05.000Z, 2016-09-21',
      example: '2016-09-21'
    }
  },
  exits: {
    success: {
      outputDescription: 'Bulk charges retrieved'
    }

  },

  fn: function ({ apiKey, ...params }, exits) {
    const queryParams = _.isEmpty(params) ? null : getQueryStringFromObject(params)
    const endpoint = _.isNull(queryParams) ? '/bulkcharge' : `bulkcharge?${queryParams}`
    makeRequest(endpoint, {
      headers: getHeaders(apiKey || process.env.PAYSTACK_API_KEY)
    }).then(bulkChargesRetrieved => exits.success(bulkChargesRetrieved))
      .catch(error => exits.error(error))
  }

}
