const { getHeaders } = require('../helpers/get-headers')
const { getQueryStringFromObject } = require('../helpers/get-query-string-from-object')
const _ = require('@sailshq/lodash')
const { makeRequest } = require('../helpers/make-request')
module.exports = {
  friendlyName: 'List transfer recipients',
  description: 'List transfer recipients available on your integration',
  cacheable: false,
  sync: false,
  inputs: {
    apiKey: require('../constants/apiKey.input'),
    perPage: require('../constants/perPage.input'),
    page: require('../constants/page.input'),
    from: {
      description: 'A timestamp from which to start listing transfer recipients',
      example: '2021-01-01'
    },
    to: {
      description: 'A timestamp at which to stop listing transfer recipients',
      example: '2021-04-01'
    }
  },
  exits: {
    success: {
      description: 'Done.'
    }
  },
  fn: function ({ apiKey, ...params }, exits) {
    const definedParams = _.isEmpty(params) ? {} : _.pick(params, _.identity)
    const queryParams = _.isEmpty(definedParams) ? null : getQueryStringFromObject(definedParams)
    const endpoint = _.isNull(queryParams) ? '/transferrecipient' : `/transferrecipient?${queryParams}`

    makeRequest(endpoint,
      {
        headers: getHeaders(apiKey || process.env.PAYSTACK_API_KEY)
      }).then((retrievedTransferRecipients) => {
      return exits.success(retrievedTransferRecipients)
    }).catch(error => {
      return exits.error(error)
    })
  }

}
