
const { getHeaders } = require('../helpers/get-headers')
const { getQueryStringFromObject } = require('../helpers/get-query-string-from-object')
const { makeRequest } = require('../helpers/make-request')
const _ = require('@sailshq/lodash')
module.exports = {

  friendlyName: 'List transfers',

  description: 'List the transfers made on your integration.',

  cacheable: false,

  sync: false,

  inputs: {
    apiKey: require('../constants/apiKey.input'),
    perPage: require('../constants/perPage.input'),
    page: require('../constants/page.input'),
    customer: {
      description: 'Filter by customer ID',
      example: 'CUS_qmwfaz7kpmnu06k'
    },
    from: {
      description: 'A timestamp from which to start listing transfer',
      example: '2021-01-01'
    },
    to: {
      description: 'A timestamp at which to stop listing transfer',
      example: '2021-04-01'
    }
  },

  exits: {

    success: {
      variableName: 'result',
      description: 'Done.'
    }

  },

  fn: function ({ apiKey, ...params }, exits) {
    const queryParams = getQueryStringFromObject(params)
    const endpoint = _.isNull(queryParams) ? '/transfer' : `/transfer?${queryParams}`
    makeRequest(endpoint,
      {
        headers: getHeaders(apiKey || process.env.PAYSTACK_API_KEY)
      }).then((retrievedTransfers) => {
      return exits.success(retrievedTransfers)
    }).catch(error => {
      return exits.error(error)
    })
    return exits.success()
  }

}
