const { getHeaders } = require('../helpers/get-headers')
const { makeRequest } = require('../helpers/make-request')

module.exports = {

  friendlyName: 'Resolve a Dispute',

  description: 'Resolve a dispute on your integration',

  cacheable: false,

  sync: false,

  inputs: {
    apiKey: require('../constants/apiKey.input'),
    id: {
      description: 'The dispute ID',
      example: '1234',
      required: true
    },
    resolution: {
      description: 'Dispute resolution',
      extendedDescription: 'Accepted values: { merchant-accepted | declined }',
      example: 'merchant-accepted',
      required: true
    },
    message: {
      description: 'Reason for resolving',
      example: 'Service was offered',
      required: true
    },
    refund_amount: {
      description: 'the amount to refund, in kobo if currency is NGN, pesewas if currency is GHS and cents if currency is in USD',
      example: 10000,
      required: true
    },
    upload_filename: {
      description: 'filename of attachment returned via response from upload url(GET /dispute/:id/upload_url)',
      example: 'filename.pdf',
      required: true
    },
    evidence: {
      description: 'Evidence ID for fraud claim',
      example: 123
    }
  },

  exits: {

    success: {
      outputDescription: 'Dispute successfully resolved'
    }

  },

  fn: function ({ apiKey, id, ...bodyParams }, exits) {
    makeRequest(`/dispute/${id}/resolve`, {
      method: 'PUT',
      headers: getHeaders(apiKey || process.env.PAYSTACK_API_KEY),
      body: JSON.stringify(bodyParams)
    }).then(resolvedDispute => exits.success(resolvedDispute))
      .catch(error => exits.error(error))
  }
}
