const { getHeaders } = require('../helpers/get-headers')
const { makeRequest } = require('../helpers/make-request')
module.exports = {
  friendlyName: 'Submit Address',
  description: 'Submit address to continue a charge',
  cacheable: false,
  sync: false,
  inputs: {
    apiKey: require('../constants/apiKey.input'),
    address: {
      description: 'Address submitted by user',
      example: '140 N 2ND ST',
      required: true
    },
    reference: {
      description: 'Reference for transaction that requested pin',
      example: 'zuvbpizfcf2fs7y',
      required: true
    },
    city: {
      description: 'City submitted by user',
      example: 'Stroudsburg',
      required: true
    },
    state: {
      description: 'State submitted by user',
      example: 'PA',
      required: true
    },
    zip_code: {
      description: 'Zip code submitted by user',
      example: '18360',
      required: true
    }
  },
  exits: {
    success: {
      outputDescription: 'Charge attempted'
    }
  },
  fn: function ({ apiKey, ...bodyParams }, exits) {
    makeRequest('/charge/submit_address', {
      method: 'POST',
      headers: getHeaders(apiKey || process.env.PAYSTACK_API_KEY),
      body: JSON.stringify(bodyParams)
    })
      .then(chargeAttempted => exits.success(chargeAttempted))
      .catch(error => exits.error(error))
  }
}
