const { getHeaders } = require('../helpers/get-headers')
const { makeRequest } = require('../helpers/make-request')

module.exports = {
  friendlyName: 'Submit OTP',
  description: 'Submit OTP to complete a charge',
  cacheable: false,
  sync: false,
  inputs: {
    apiKey: require('../constants/apiKey.input'),
    otp: {
      description: 'OTP submitted by user',
      example: '123456',
      required: true
    },
    reference: {
      description: 'Reference for transaction that requested otp',
      example: 'zuvbpizfcf2fs7y',
      required: true
    }
  },
  exits: {
    success: {
      outputDescription: 'Charge attempted'
    }
  },
  fn: function ({ apiKey, ...bodyParams }, exits) {
    makeRequest('/charge/submit_otp', {
      method: 'POST',
      headers: getHeaders(apiKey || process.env.PAYSTACK_API_KEY),
      body: JSON.stringify(bodyParams)
    })
      .then(chargeAttempted => exits.success(chargeAttempted))
      .catch(error => exits.error(error))
  }

}
