const { getHeaders } = require('../helpers/get-headers')
const { makeRequest } = require('../helpers/make-request')
module.exports = {
  friendlyName: 'Submit Pin',
  description: 'Submit PIN to continue a charge',
  cacheable: false,
  sync: false,
  inputs: {
    apiKey: require('../constants/apiKey.input'),
    pin: {
      description: 'PIN submitted by user',
      example: '1234',
      required: true
    },
    reference: {
      description: 'Reference for transaction that requested pin',
      example: 'zuvbpizfcf2fs7y',
      required: true
    }
  },
  exits: {
    success: {
      outputDescription: 'Charge attempted'
    }
  },
  fn: function ({ apiKey, ...bodyParams }, exits) {
    makeRequest('/charge/submit_pin', {
      method: 'POST',
      headers: getHeaders(apiKey || process.env.PAYSTACK_API_KEY),
      body: JSON.stringify(bodyParams)
    })
      .then(chargeAttempted => exits.success(chargeAttempted))
      .catch(error => exits.error(error))
  }
}
