const { getHeaders } = require('../helpers/get-headers')
const { makeRequest } = require('../helpers/make-request')

module.exports = {
  friendlyName: 'Update Payment Session Timeout',
  description: 'Update the payment session timeout on your integration',
  cacheable: false,
  sync: false,
  inputs: {
    apiKey: require('../constants/apiKey.input'),
    timeout: {
      description: 'Time before stopping session (in seconds)',
      extendedDescription: 'Set to 0 to cancel session timeouts',
      example: 30,
      required: true
    }
  },
  exits: {
    success: {
      outputDescription: 'Payment session timeout updated'
    }
  },

  fn: function ({ apiKey, ...bodyParams }, exits) {
    makeRequest('/integration/payment_session_timeout', {
      method: 'PUT',
      headers: getHeaders(apiKey || process.env.PAYSTACK_API_KEY),
      body: JSON.stringify(bodyParams)
    }).then(updatedSession => exits.success(updatedSession))
      .catch(error => exits.error(error))
  }

}
