const { getHeaders } = require('../helpers/get-headers')
const { makeRequest } = require('../helpers/make-request')
module.exports = {

  friendlyName: 'Update transfer recipient',

  description: 'Update an existing recipient. An duplicate account number will lead to the retrieval of the existing record.',

  cacheable: false,

  sync: false,

  inputs: {
    apiKey: require('../constants/apiKey.input'),
    id_or_code: {
      description: 'Transfer Recipient\'s ID or code',
      example: '27',
      required: true
    },
    name: {
      description: 'A name for the recipient',
      example: 'Kelvin Omereshone',
      required: true
    },
    email: {
      description: 'Email address of the recipient',
      example: 'kelvin@example.org',
      required: true
    },
    description: {
      description: 'A description for the recipient',
      example: 'Sailscasts payout'
    }

  },

  exits: {
    success: {
      variableName: 'result',
      description: 'Done.'
    }
  },

  fn: function ({ apiKey, id_or_code, ...bodyParams }, exits) {
    makeRequest(`/transferrecipient/${id_or_code}`,
      {
        method: 'PUT',
        headers: getHeaders(apiKey || process.env.PAYSTACK_API_KEY),
        body: JSON.stringify(bodyParams)
      }).then((updatedTransferRecipient) => {
      return exits.success(updatedTransferRecipient)
    }).catch(error => {
      return exits.error(error)
    })
  }

}
